@@ -1,7 +1,7 @@
 /*
  * Big Endian <-> Host byte order converter
  *
- * $Id: htobe.h,v 1.1.2.1 2001/03/19 20:16:04 masayu-a Exp $
+ * $Id: htobe.h,v 1.1.2.2 2001/03/21 18:01:40 masayu-a Exp $
  */
 
 #include "config.h"
@@ -33,5 +33,8 @@
 #define htobe __htobe
 #define betoh __betoh
 #endif /* HAVE_HTONL */
+#else /* WORDS_BIGENDIAN */
+#define htobe
+#define betoh
 #endif /* WORDS_BIGENDIAN */
 #endif /* __HTOBE_H__ */
