@@ -36,7 +36,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Modified by: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Oct. 1996
- * $Id: parse.c,v 1.24.4.1 2001/04/17 08:11:23 masayu-a Exp $
+ * $Id: parse.c,v 1.24.4.6 2001/06/21 05:37:36 masayu-a Exp $
  */
 
 #include "chalib.h"
@@ -314,6 +314,7 @@ collect_mrphs_for_pos(int pos, int *p_idx)
     return j;
 }
 
+
 /*
  * check_connect()
  */
@@ -477,7 +478,7 @@ set_mrph_end(mrph2_t * mrph)
     mrph->midasi = mrph->yomi = mrph->info = "";
     mrph->base = mrph->pron = "";
     mrph->compound = "\n";
-    mrph->base_length = mrph->length = 3;
+    mrph->base_length = mrph->length = 0;
 
     mrph->hinsi = 0;
     mrph->ktype = 0;
@@ -524,7 +525,7 @@ lookup_dic(char *target, int target_len, int cursor, int new_mrph_idx)
     /*
      * (ʸΤ߸) EUC only 
      */
-    if (Cha_encode == CHASEN_ENCODE_EUC &&
+    if (Cha_encode == CHASEN_ENCODE_EUCJP &&
 	cha_tok_mblen_on_cursor(Cha_tokenizer, cursor) == 2) {
 	for (dic_no = 0; dic_no < Pat_ndicfile; dic_no++) {
 	    int nmrph;
@@ -575,9 +576,6 @@ set_undefword(char *target, int cursor, int new_mrph_idx, int mrph_idx,
     int i;
 
     undef_len = cha_tok_char_type_len(Cha_tokenizer, cursor);
-#if 0
-    printf("# cursor: %d, undef_len: %d\n", cursor, undef_len);
-#endif
     /*
      * ľΥѥȤ³å 
      */
@@ -655,7 +653,7 @@ add_bkugiri(int cursor, int *path_idx, int path_idx_num, int bkugiri_num)
 int
 cha_parse_sentence(char *target, int target_len, int opt_nobk)
 {
-    int cursor, cursor_end;
+    int cursor, prev_cursor;
     int path_idx[PATH1_NUM], path_idx_num;
     int mrph_idx, new_mrph_idx;
     int bkugiri_num = 0;
@@ -668,7 +666,7 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
     free_mrph();
 
     /*
-     * ʸƬ 
+     * ʸƬ
      */
     Cha_path[0].start = Cha_path[0].end = 0;
     Cha_path[0].path = &path0;
@@ -682,36 +680,38 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
 	bkugiri_num = set_mrph_bkugiri();
     new_mrph_idx = mrph_idx = bkugiri_num + 1;
 
-    for (cursor = cursor_end = 0; cursor <= target_len;
+    /*
+     * ܽ
+     */
+    for (cursor = prev_cursor = 0; cursor < target_len;
 	cursor += cursor_sep(cursor, target_len - cursor)) {
-#if 0
-	printf("# mrph %d\n", mrph_idx);
-#endif
 
-	cursor_end = cursor;
+        prev_cursor = cursor;
 	/* skip annotations and white space */
 	while (cha_tok_anno_type(Cha_tokenizer, cursor) != 0 ) {
 	    cursor += cha_tok_char_type_len(Cha_tokenizer, cursor);
 	    if (cursor > target_len)
 		break;
 	}
+	
+	path_idx_num = collect_mrphs_for_pos(prev_cursor, path_idx);
 
-	path_idx_num = collect_mrphs_for_pos(cursor_end, path_idx);
-#if 0
-	printf("# path_idx_num %d\n", path_idx_num);
-#endif
 	if (path_idx_num == 0)
 	    continue;
 
+	/* add BUNSETSU (the POS with length 0) information */
 	path_idx_num = add_bkugiri(cursor,
 				   path_idx, path_idx_num, bkugiri_num);
 	if (path_idx_num < 0)
 	    goto error_end;
 
+	/* pick up possible words from dictionary */
 	new_mrph_idx = lookup_dic(target, target_len, cursor, new_mrph_idx);
 	if (new_mrph_idx < 0)
 	    goto error_end;
 
+	/* set undefined word */
+	/* check the path between the preceding and current position  */
 	new_mrph_idx = set_undefword(target, cursor,
 				     new_mrph_idx, mrph_idx, path_idx);
 	if (new_mrph_idx < 0)
@@ -721,36 +721,25 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
     }
 
     /*
-     * ʸ 
+     * ʸ
      */
-    set_mrph_end(&Cha_mrph[mrph_idx-1]);
-    if (++mrph_idx % MRPH_NUM == 0 && malloc_mrph())
-	goto error_end;
+    set_mrph_end(&Cha_mrph[mrph_idx++]);
+    if (mrph_idx % MRPH_NUM == 0 && malloc_mrph())
+        goto error_end;
+    
+    path_idx_num = collect_mrphs_for_pos(cursor, path_idx);
 
-    collect_mrphs_for_pos(cursor_end, path_idx);
     if (check_connect(cursor, mrph_idx - 1, path_idx) == FALSE)
-	goto error_end;
-
-#ifdef DEBUG
-    for (i = 1; i < mrph_idx - 1; i++) {
-	printf("%4d: %4d ", i, Cha_mrph[i].con_tbl);
-	print_mrph(0, &Cha_mrph[i], 'F',
-		   "%-11m %-11y %-11P3- %-14T  %F \n");
-    }
-#endif
-
-#if 0
-    printf("# num - mrph:%d path:%d, size - mrph:%d path:%d \n",
-	   mrph_idx, Cha_path_num, sizeof(mrph2_t), sizeof(path_t));
-#endif
+        goto error_end;
 
+ 
     return 0;
 
+    /*
+     * 顼
+     */
   error_end:
     printf("Error: Too many morphs: %s\n", target);
-#if 0
-    printf("# num - mrph:%d path:%d, size - mrph:%d path:%d \n",
-	   mrph_idx, Cha_path_num, sizeof(mrph2_t), sizeof(path_t));
-#endif
+
     return 1;
 }
